@@ -2,6 +2,7 @@ import uuid
 from itertools import product
 from typing import List
 
+import inject
 import pytest  # type:ignore[import]
 from maus.models.anwendungshandbuch import AhbMetaInformation, DeepAnwendungshandbuch
 from maus.models.edifact_components import (
@@ -63,6 +64,8 @@ class TestValidation:
             edifact_format_version=default_test_version,
             evaluatable_data_provider=eval_data_provider,
         )
+        yield
+        inject.clear()
 
     @pytest.mark.parametrize(
         "deep_ahb, expected_validation_result",
